@@ -1,5 +1,5 @@
-{package POEx::Role::SessionInstantiation::Meta::Session::Events;
-$POEx::Role::SessionInstantiation::Meta::Session::Events::VERSION = '1.100911';}
+package POEx::Role::SessionInstantiation::Meta::Session::Events;
+$POEx::Role::SessionInstantiation::Meta::Session::Events::VERSION = '1.100912';
 
 #ABSTRACT: Provides default events such as _start, _stop, etc
 
@@ -61,7 +61,7 @@ POEx::Role::SessionInstantiation::Meta::Session::Events - Provides default event
 
 =head1 VERSION
 
-version 1.100911
+version 1.100912
 
 =head1 PRIVATE_METHODS
 
